/* Jatha -- bringing to Java some of the power of lisp.
 * Copyright (C) 2001  Kimberley Burchett   kimbly@pobox.com
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package macros;

import java.io.*;
import jatha.*;

/**
 * <code>CLASS(name)</code>
 * 
 * <p>The CLASS macro provides very little utility on its own, but it is
 * necessary in order to use the CTOR macro later.  Example: 
 * 
 * <pre>
 * public @CLASS(MyClass) {
 *     ...
 * }
 * </pre>
 *
 * <p>Will generate this:
 * 
 * <pre>
 * public class MyClass {
 *     ...
 * }
 * </pre>
 * 
 * <p>This macro only comes in handy when used together with other macros, 
 * because it leaves a message recording the name of the class.  For example, 
 * the CTOR macro uses this message so that you don't need to tell it the 
 * name of the class.
 * 
 * @see macros.CTOR
 */
public class CLASS extends Macro {
	/** Expands the macro */
	public void expand(String[] args, Writer out, Expander expander) throws IOException {
		if (args.length != 1)
			expander.error("@CLASS requires exactly one argument");
		out.write("class ");
		out.write(args[0]);

		expander.leaveMessage("CLASS`name", args[0]);
	}
}
