/* Jatha -- bringing to Java some of the power of lisp.
 * Copyright (C) 2001  Kimberley Burchett   kimbly@pobox.com
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package macros;

import java.io.*;
import jatha.*;

/**
 * <code>ENUM_BITS(elem1, elem2, ...)</code>
 * 
 * <p>This macro creates a bitfield enumeration.  That is, each element 
 * of the enumeration is a power of 2, allowing several elements to be
 * bitwise OR'ed together.
 * 
 * Example: <code>@ENUM_BITS(BLAH, QWERTY, ELMO)</code>
 * will generate something like this:
 * <pre>
 * public static final int BLAH = 1;
 * public static final int QWERTY = 2;
 * public static final int ELMO = 4;
 * </pre>
 * 
 * <p>Note: this macro only declares some member variables; it doesn't 
 * declare an entire class like ENUM_OBJ.
 * 
 * @see macros.ENUM_OBJ
 * @see macros.ENUM_INT
 */
public class ENUM_BITS extends Macro {
	/** Expands the macro */
	public void expand(String[] args, Writer out, Expander expander) throws IOException {
		if (args.length < 1)
			expander.error("ENUM_BITS requires at least one argument");

		for (int i=0; i < args.length; ++i) {
			if (i != 0) out.write("\t");
			out.write("public static final int "+args[i]+" = "+(1<<i)+";\n");
		}
	}
}
