/* Jatha -- bringing to Java some of the power of lisp.
 * Copyright (C) 2001  Kimberley Burchett   kimbly@pobox.com
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package macros;

import java.io.*;
import jatha.*;

/**
 * <code>INCLUDE(filename)</code>
 * 
 * <p>Inserts the contents of the specified file, similar to the C-style #include.
 * However, if the included file has macros, they will not be processed.
 */
public class INCLUDE extends Macro {
	/** Expands the macro */
	public void expand(String[] args, Writer out, Expander expander) {
		if (args.length != 1)
			expander.error("INCLUDE macro takes one argument: filename");

		try {
			File inFile = new File(expander.getFile().getParentFile(), args[0]);
			Reader in = new BufferedReader(new FileReader(inFile));
			int c = in.read();
			while (c != -1) {
				out.write(c);
				c = in.read();
			}
			in.close();
		}
		catch (FileNotFoundException e) {
			expander.error("Unable to open file "+args[0]+": "+e.getMessage());
		}
		catch (IOException e) {
			expander.error("IO error while reading file "+args[0]+": "+e.getMessage());
		}
	}
}
